library(tidyverse)
theme_set(theme_bw())

meta <- read_csv('subjects-metadata.csv')

extra_subjects <- tibble(
  n_omitted = 0,
  subject = c(
    "nfc-2018-09-21-1-6", "nfc-2018-09-21-1-20",
    "nfc-2018-09-21-1-9", "nfc-2018-09-20-9"
  ),
  hm = 0
)

exp <- read_csv('hm-scores.csv') %>%
  bind_rows(extra_subjects %>% select(subject, n_omitted, hm)) %>%
  complete(subject, n_omitted, fill=list(hm=0)) %>%
  inner_join(meta, by='subject') %>%
  group_by(fc, n_omitted) %>%
  summarise(
    n_zero = sum(hm == 0),
    n_nonzero = sum(hm > 0),
    p = mean(hm == 0),
    p_se = sd(hm == 0) / sqrt(n()),
    .groups = 'drop'
  ) %>%
  write_csv('proportions.csv')

ggplot(exp %>% mutate(choice = if_else(fc == 1, 'FC', 'NFC')), aes(n_omitted, p, colour=choice)) +
  geom_line() +
  geom_point() +
  geom_ribbon(aes(ymin=p-p_se, ymax=p+p_se, fill=choice), alpha=0.3, colour=NA) +
  ylab('p') +
  xlab('n_omitted')

ggsave('proportions.png', width=7, height=4, dpi=96)
