#!/usr/bin/env bash

# catch errors early
set -euo pipefail

# input file with experimental data
INFILE="${INFILE:-Exp1_2_PREST.csv}"

# path to the Prest repository
PRESTDIR="${PRESTDIR:-../../../dev/prest}"

# build and run the HM utility
prest_hm() {
  (cd ${PRESTDIR}/core; cargo run --quiet --release --bin hm)
}

# produce a CSV for the dataset where
# first N observations have been omitted for each subject
hm_scores() {
  n_omitted="$1"

  cat "$INFILE" \
    | xsv select 'position,subject,menu,choice' \
    | ./filter.py drop --first "$n_omitted" \
    | ./filter.py drop --deferrals \
    | xsv select '!position' \
    | prest_hm \
    | sed -e "1s/\$/,n_omitted/" -e "2,\$s/\$/,${n_omitted}/"
}

# elementary dependency check
if ! which xsv &>/dev/null; then
  echo "'xsv' is missing. You can install it using 'cargo install xsv'" >&2
  echo "or download a version from https://github.com/BurntSushi/xsv" >&2
  exit 1
fi

if ! which python &>/dev/null; then
  echo "No Python installation found. Please install Python." >&2
  exit 1
fi

if ! [ -d "${PRESTDIR}/core" ]; then
  echo "No Prest repository has been found in ${PRESTDIR}." >&2
  echo "Please check it out and/or update the PRESTDIR variable in the script." >&2
  exit 1
fi

# compute the HM scores for subjects with dropped observations
xsv cat rows \
  <(hm_scores 0) <(hm_scores 1) <(hm_scores 2) \
  <(hm_scores 3) <(hm_scores 4) <(hm_scores 5) \
  > hm-scores.csv

# analyse the data
# this produces proportions.csv and proportions.png
R -q -f analyse.R

# pretty-print the output
xsv table proportions.csv
